@@ -4,7 +4,7 @@ do everything that deals with commands (rsync & others) execution
 ===============================================================================================================================
 ===============================================================================================================================
     This file is part of "luckyBackup" project
-    Copyright 2008-2012, Loukas Avgeriou
+    Copyright, Loukas Avgeriou
     luckyBackup is distributed under the terms of the GNU General Public License
     luckyBackup is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ do everything that deals with commands (rsync & others) execution
 project version	: Please see "main.cpp" for project version
 
 developer          : luckyb 
-last modified      : 12 Mar 2012
+last modified      : 10 Feb 2014
 ===============================================================================================================================
 ===============================================================================================================================
 ********************************** DO NOT FORGET TO CHANGE "commandline.cpp:rsyncIT()" ********************************************************
@@ -63,6 +63,8 @@ void luckyBackupWindow::executeNOW ()
     ExecuteAfter=FALSE;
     writeToLog=FALSE;
     errorsFound = 0;		//total error founds during profile execution
+    filesTransfered = 0;    //total bytes transfered during profile execution
+    bytesTransfered = 0;    //total bytes transfered during profile execution
     count = 0;
     currentAfter = 0;
     currentBefore = 0;
@@ -98,6 +100,30 @@ void luckyBackupWindow::executeNOW ()
     connect ( ui.AbortButton, SIGNAL( clicked() ), this, SLOT( abortPressed() ) );	//connect abort pushButton SLOT ----------------
     connect ( ui.DoneButton, SIGNAL( clicked() ), this, SLOT( donePressed() ) );	//connect done pushButton SLOT ----------------
 
+/*    if (WINrunning)           // disable VSS until...
+    {
+      vssTimer= new QTimer(this);
+
+        pipeVssFile =  new QFile(tempDirPath+SLASH+"qt_tempvss"+QString::number(qrand() % (999998) + 1));
+        if (pipeVssFile->open(QIODevice::ReadWrite))
+        {
+            pipeVssFile->close();
+//            if (pipeVssFile->open(QIODevice::ReadOnly | QIODevice::Text))
+//              connect(pipeVssFile,SIGNAL(readyRead()),this,SLOT(appendRsyncVssOutput()));
+        }
+        pipeVssErrFile =  new QFile(tempDirPath+SLASH+"qt_tempvsserr"+QString::number(qrand() % (999998) + 1));
+        if (pipeVssErrFile->open(QIODevice::ReadWrite)){
+            pipeVssErrFile->close();
+//            if (pipeVssErrFile->open(QIODevice::ReadOnly | QIODevice::Text))
+//              connect(pipeVssErrFile,SIGNAL(readyRead()),this,SLOT(appendRsyncVssOutput()));
+        }
+        if (Operation[currentOperation]->GetOptionsVss())
+        {
+            connect (vssTimer,SIGNAL(timeout()),this,SLOT(appendRsyncVssOutput()));
+            vssTimer->start(vssSleepTime);
+        }
+    }*/
+      
     syncProcess = new QProcess(this);	//create a new qprocess (for rsync) & connect signals
     connect(syncProcess, SIGNAL(readyReadStandardError()), this, SLOT(appendRsyncOutput()));
     connect(syncProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(appendRsyncOutput()));
@@ -382,37 +408,65 @@ void luckyBackupWindow::executeBeforeTask()
         // First calculate the folder where snapshots go (tempDestination)
         QStringList tempArguments = Operation[currentOperation] -> GetArgs();
         QString tempSource = tempArguments[tempArguments.size()-2];
-        QString tempDestination = tempArguments[tempArguments.size()-1];
+        QString tempDestination     = tempArguments[tempArguments.size()-1];
+        QString tempDestinationOrig = tempArguments[tempArguments.size()-1];
+        QString tempDestinationOrig2;
         QString sourceLast = tempSource;
         if (!tempSource.endsWith(SLASH))    // this means task is of type "backup dir by name"
         {
             sourceLast = calculateLastPath(sourceLast); // This is the lowest dir of the source
             
             tempSource.append(SLASH);
-            tempDestination.append(sourceLast + SLASH);
+            if (WINrunning && RemoteDestUsed)
+                tempDestination.append(sourceLast + XnixSLASH);
+            else
+                tempDestination.append(sourceLast + SLASH);
         }
-        tempDestination.append (snapDefaultDir);
+        tempDestinationOrig2=tempDestination;
+        if (RemoteDestUsed && WINrunning)
+            tempDestination.append (snapDefaultDir.replace(SLASH,XnixSLASH));
+        else
+            tempDestination.append (snapDefaultDir);
         
         QStringList remoteArgs; remoteArgs.clear();
         //all remote arguments exactly as used at normal backup
         if (RemoteDestUsed)
         {
             remoteArgs.append("--protect-args");
-            if ( Operation[currentOperation] -> GetRemotePassword() != "")
+            //if ( Operation[currentOperation] -> GetRemotePassword() != "")
+            if ( Operation[currentOperation]-> GetRemoteModule() && Operation[currentOperation] -> GetRemotePassword() != "")
                 remoteArgs.append("--password-file=" + ( Operation[currentOperation] -> GetRemotePassword()) );
             if ( Operation[currentOperation] -> GetRemoteSSH())
             {
-                if ( Operation[currentOperation] -> GetRemoteSSHPassword() != "")
-                    if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
-                        remoteArgs.append("-e "+sshCommandPath+" -i " +  Operation[currentOperation] -> GetRemoteSSHPassword() +" -p " +
-                                    countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+                QString sshOptions=(Operation[currentOperation] -> GetRemoteSSHOptions()).replace("\"","\\\"")+" -o \"StrictHostKeyChecking no\"  -o \"PasswordAuthentication no\" ";
+                if (WINrunning)
+                {
+                    if ( Operation[currentOperation] -> GetRemoteSSHPassword() != "")
+                        if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+                        remoteArgs.append("-e \""+Operation[currentOperation] -> GetSshCommand()+"\" "+sshOptions+" -i \"" +  Operation[currentOperation] -> GetRemoteSSHPassword() +"\" -p " +
+                                        countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+                        else
+                        remoteArgs.append("-e \""+Operation[currentOperation] -> GetSshCommand()+"\" "+sshOptions+" -i \"" +  Operation[currentOperation] -> GetRemoteSSHPassword()+"\"");
                     else
-                        remoteArgs.append("-e "+sshCommandPath+" -i " +  Operation[currentOperation] -> GetRemoteSSHPassword());
+                        if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+                        remoteArgs.append("-e \""+Operation[currentOperation] -> GetSshCommand()+"\" "+sshOptions+" -p " + countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+                        else
+                            remoteArgs.append("-e \""+Operation[currentOperation] -> GetSshCommand()+"\" "+sshOptions+"");
+                }
                 else
-                    if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
-                        remoteArgs.append("-e "+sshCommandPath+" -p " + countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+                {
+                    if ( Operation[currentOperation] -> GetRemoteSSHPassword() != "")
+                        if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+                            remoteArgs.append("-e "+sshCommandPath+" -i " +  Operation[currentOperation] -> GetRemoteSSHPassword() +" -p " +
+                                        countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+                        else
+                            remoteArgs.append("-e "+sshCommandPath+" -i " +  Operation[currentOperation] -> GetRemoteSSHPassword());
                     else
-                        remoteArgs.append("-e "+sshCommandPath);
+                        if ( Operation[currentOperation] -> GetRemoteSSHPort() != 0)
+                            remoteArgs.append("-e "+sshCommandPath+" -p " + countStr.setNum( Operation[currentOperation] -> GetRemoteSSHPort()) );
+                        else
+                            remoteArgs.append("-e "+sshCommandPath);
+                }
             }
         }
         
@@ -441,11 +495,17 @@ void luckyBackupWindow::executeBeforeTask()
             int snapToKeep = currentSnaps-maxSnaps + 1;
             while ( snapToKeep < currentSnaps )
             {
-                rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + SLASH);
+                if (WINrunning && RemoteDestUsed)
+                    rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + XnixSLASH);
+                else
+                    rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + SLASH);
                 snapToKeep++;
             }
             // protect the backup profile dir too
-            rmArgs.append("--filter=protect " + profileName + ".profile" + SLASH);
+            if (WINrunning && RemoteDestUsed)
+                rmArgs.append("--filter=protect " + profileName + ".profile" + XnixSLASH);
+            else
+                rmArgs.append("--filter=protect " + profileName + ".profile" + SLASH);
             
             //also add all remote arguments exactly as used at normal backup
             if (RemoteDestUsed)
@@ -455,7 +515,19 @@ void luckyBackupWindow::executeBeforeTask()
             rmArgs.append(snapEmptyDir);
             rmArgs.append(tempDestination);
             
-            rmProcess -> start (command,rmArgs);
+            if (WINrunning)
+            {
+
+                //bool createWinRsyncCommand(tempDirPath,QFile command1,QFile command2,bool vss,QString rsyncArgs,QString source,QString dest);
+                QString command2=createWinRsyncCommand(tempDirPath,false,rmArgs);
+                ui.rsyncOutput->append("\n"+command2);
+                if (command2=="")
+                    cout << "\nfailed to create bat file in rmProccess";
+                else
+                    rmProcess -> start (command2);
+            }
+            else
+                rmProcess -> start (command,rmArgs);
             rmProcess -> waitForFinished();
             
             if ((rmProcess -> exitCode()) == 0)
@@ -503,6 +575,10 @@ void luckyBackupWindow::executeBeforeTask()
             QProcess *mkdirProcess;
             mkdirProcess  = new QProcess(this);
             QStringList mkdirArgs;      mkdirArgs.clear();
+            //no needed any more
+            //if ( (WINrunning) && (RemoteDestUsed) )
+            //    mkdirArgs << "--mkdir";
+            //else
             mkdirArgs << "--progress" << "-r";
             
             //add all remote arguments exactly as used at normal backup
@@ -511,15 +587,73 @@ void luckyBackupWindow::executeBeforeTask()
                 mkdirArgs << remoteArgs;
             
             mkdirArgs.append(snapEmptyDir);
-            mkdirArgs.append(tempDestination);
-            mkdirProcess -> start (command,mkdirArgs);
-            mkdirProcess -> waitForFinished();
             
+            //rsync throws error if directory is not yet created, ..so create it first
+            
+            // Add the destination folder
+            mkdirArgs.append(tempDestinationOrig);  // this is actually an empty argument
+            if (WINrunning)
+            {
+                //bool createWinRsyncCommand(tempDirPath,QFile command1,QFile command2,bool vss,QString rsyncArgs,QString source,QString dest);
+                QString command2=createWinRsyncCommand(tempDirPath,false,mkdirArgs);
+                ui.rsyncOutput->append("\n"+command2);
+                if (command2=="")
+                    cout << "\nfailed to create bat file in mkdirProccess";
+                else
+                    mkdirProcess -> start (command2);
+            }
+            else
+                mkdirProcess -> start (command,mkdirArgs);
+            
+            mkdirProcess -> waitForFinished();
+            if ((mkdirProcess -> exitCode()) == 0)
+                ui.rsyncOutput->append("\n!!");
+            else
+                ui.rsyncOutput->append("\n!");
+            mkdirArgs.removeLast(); //remove the tempDestinationOrig argument
+            
+            // Add the destination folder [ + sourceLast +SLASH ]
+            mkdirArgs.append(tempDestinationOrig2);  // this is actually an empty argument
+            if (WINrunning)
+            {
+                //bool createWinRsyncCommand(tempDirPath,QFile command1,QFile command2,bool vss,QString rsyncArgs,QString source,QString dest);
+                    QString command2=createWinRsyncCommand(tempDirPath,false,mkdirArgs);
+                    ui.rsyncOutput->append("\n"+command2);
+                if (command2=="")
+                    cout << "\nfailed to create bat file in mkdirProccess";
+                else
+                    mkdirProcess -> start (command2);
+            }
+            else
+                mkdirProcess -> start (command,mkdirArgs);
+
+            mkdirProcess -> waitForFinished();
             if ((mkdirProcess -> exitCode()) == 0)
                 ui.rsyncOutput->append("\n!!");
             else
                 ui.rsyncOutput->append("\n!");
             
+            // Add the destination folder [ + sourceLast +SLASH ] + snapDefaultDir
+            mkdirArgs.removeLast(); //remove the tempDestinationOrig2 argument
+            mkdirArgs.append(tempDestination);
+            if (WINrunning)
+            {
+                //bool createWinRsyncCommand(tempDirPath,QFile command1,QFile command2,bool vss,QString rsyncArgs,QString source,QString dest);
+                    QString command2=createWinRsyncCommand(tempDirPath,false,mkdirArgs);
+                    ui.rsyncOutput->append("\n"+command2);
+                if (command2=="")
+                    cout << "\nfailed to create bat file in mkdirProccess";
+                else
+                    mkdirProcess -> start (command2);
+            }
+            else
+                mkdirProcess -> start (command,mkdirArgs);
+            
+            mkdirProcess -> waitForFinished();
+            if ((mkdirProcess -> exitCode()) == 0)
+                ui.rsyncOutput->append("\n!!");
+            else
+                ui.rsyncOutput->append("\n!");
         }
 
         //set the current date and time as the operation's last execution date-time
@@ -704,7 +838,18 @@ void luckyBackupWindow::executeRsync()
     
     ProcReportedError = FALSE;      // This might change as soon as syncprocess will start ()
 
-    syncProcess -> start (command,rsyncArguments);	// execute rsync command with rsyncArguments
+    if (WINrunning)
+    {
+        //bool createWinRsyncCommand(tempDirPath,QFile command1,QFile command2,bool vss,QString rsyncArgs,QString source,QString dest);
+        QString command2=createWinRsyncCommand(tempDirPath,Operation[currentOperation]->GetOptionsVss(),rsyncArguments);
+        ui.rsyncOutput->append("\n"+command2);
+        if (command2=="")
+            cout << "\nfailed to create bat file for vss";
+        else
+            syncProcess -> start (command2);
+    }
+    else
+        syncProcess -> start (command,rsyncArguments);	// execute rsync command with rsyncArguments
     
     // The reason for the below jump is that when a process reports an error it does not emit finished() signals neither std output/errors
     if (ProcReportedError)
@@ -717,6 +862,13 @@ void luckyBackupWindow::procFinished()
     if (ABORTpressed) //this is to prevent segmentation fault when abort button pressed
         return;
 
+    /* Disable VSS until
+    if (doVss==1) //reads all log file in vss before finished
+    {
+        doVss=2;
+        return;
+    }*/
+      
     bool RemoteDestUsed = (Operation[currentOperation] -> GetRemoteDestination()) && (Operation[currentOperation] -> GetRemote()); // Is remote dest used ?
     if (ExecuteBefore)		// if the pre-task execution command (process) finished
     {
@@ -835,7 +987,12 @@ void luckyBackupWindow::procFinished()
                 sourceLast = "";
             
             if (!rsyncArguments.isEmpty())      //rsyncArguments is calculated at executeRsync()
-                exportProfileDir = rsyncArguments.last() + sourceLast + SLASH + snapDefaultDir + profileName + ".profile" + SLASH;
+            {
+                if (WINrunning && RemoteDestUsed)
+                    exportProfileDir = rsyncArguments.last() + sourceLast + XnixSLASH + snapDefaultDir + profileName + ".profile" + XnixSLASH;
+                else
+                    exportProfileDir = rsyncArguments.last() + sourceLast + SLASH + snapDefaultDir + profileName + ".profile" + SLASH;
+            }
             
             //QMessageBox::information(this, "LB",exportProfileDir);    //TESTING
             
@@ -947,10 +1104,14 @@ void luckyBackupWindow::appendRsyncOutput()
     
     //update progressbar--------------------------------------------------------------------------------------------------------
     bool ok;
-    if (outputString.contains("to-check"))	//we will calculate how many files have been proccessed so far
+    if ( (outputString.contains("to-check")) || (outputString.contains("to-chk")) )	//we will calculate how many files have been proccessed so far
     {
         //DoneToTotal_Ref & DoneToTotal_String hold a e.g. "17/84"
-        QStringRef DoneToTotal_Ref = outputString.midRef(outputString.indexOf("check=")+6,outputString.indexOf(")")-outputString.indexOf("check=")-6);
+        QStringRef DoneToTotal_Ref;
+        if (outputString.contains("to-check"))  // if rsync uses "to-check="
+            DoneToTotal_Ref = outputString.midRef(outputString.indexOf("check=")+6,outputString.indexOf(")")-outputString.indexOf("check=")-6);
+        else                                    // if rsync uses "to-chk="
+            DoneToTotal_Ref = outputString.midRef(outputString.indexOf("o-chk=")+6,outputString.indexOf(")")-outputString.indexOf("o-chk=")-6);
         QString DoneToTotal_String = DoneToTotal_Ref.toString();
 
         //Total no files
@@ -989,8 +1150,151 @@ void luckyBackupWindow::appendRsyncOutput()
         transferring = FALSE;
         deleting = TRUE;
     }
+    
+    // Extraxt some data from the "stats" lines at the end of rsync
+    if ( (outputString.contains("Number of files transferred")) || (outputString.contains("Total bytes sent:")) || (outputString.contains("Number of regular files")) )
+    {
+        // split the outputString to lines
+        QString FilesTransferedString="",BytesTransferedString="";
+        QStringList lines = outputString.split( "\n", QString::SkipEmptyParts );
+        foreach( QString line, lines )
+        {
+            if (line.contains("Number of files transferred:"))
+                FilesTransferedString = line.remove("Number of files transferred: ");          // old rsync report;
+            if (line.contains("Number of regular files transferred:"))
+                FilesTransferedString = line.remove("Number of regular files transferred: ");  // newer rsync report
+            if (line.contains("Total transferred file size:"))
+                BytesTransferedString = line.remove("Total transferred file size: ");           // newer rsync report
+            if (line.contains("Total bytes sent:"))
+                BytesTransferedString = line.remove("Total bytes sent: ");             // old rsync report
+        }
+
+        filesTransfered = filesTransfered + FilesTransferedString.toInt(&ok, 10);
+
+        BytesTransferedString = convertBytes(BytesTransferedString,FALSE);       
+        bytesTransfered = bytesTransfered + BytesTransferedString.toULongLong(&ok, 10);
+    }
 }
 
+/*  disable vss until...
+void luckyBackupWindow::appendRsyncVssOutput()
+{
+    appendRsyncVssOutput(vssReadSize);
+}
+
+//Read size lines, if size=-1 read all file
+void luckyBackupWindow::appendRsyncVssOutput(int size)
+{
+    if (ABORTpressed)       //better safe than sorry :)
+        return;
+    if (doVss==0)
+    return;
+    setNowDoing ();     //update Nowdoing textBrowser
+
+
+
+    QString s,se;
+    if (pipeVssFile->open(QIODevice::ReadOnly | QIODevice::Text))
+    {
+        int i=size;
+        QTextStream stream(pipeVssFile);
+        stream.setCodec("UTF-8");
+        stream.seek(vssPos);
+        outputString="";
+        s=stream.readLine();
+        while(!s.isNull()&&i!=0){
+            outputString=outputString+s+"\n";
+            s=stream.readLine();
+            //if (!showOnlyErrors)
+            i--;
+        };
+        vssPos=stream.pos();
+        pipeVssFile->close();
+        if (outputString !="")
+        {
+            if (!ui.checkBox_onlyShowErrors -> isChecked())
+                ui.rsyncOutput->append(outputString);
+            logFileUpdate("rsync-standard", outputString, 0);
+            //update progressbar--------------------------------------------------------------------------------------------------------
+            bool ok;
+            if (outputString.contains("to-check"))  //we will calculate how many files have been proccessed so far
+            {
+                //DoneToTotal_Ref & DoneToTotal_String hold a e.g. "17/84"
+                QStringRef DoneToTotal_Ref = outputString.midRef(outputString.indexOf("check=")+6,outputString.indexOf(")")-outputString.indexOf("check=")-6);
+                QString DoneToTotal_String = DoneToTotal_Ref.toString();
+
+                //Total no files
+                QStringRef ref_temp = DoneToTotal_String.rightRef(DoneToTotal_String.size() - DoneToTotal_String.indexOf(SLASH) -1);
+                QString string_temp = ref_temp.toString();
+                progress_total = string_temp.toInt(&ok,10);
+                ui.OperationProgress -> setRange(0,progress_total); //set the range of the progressbar to the no of files to consider
+
+                //No of files processed so far
+                ref_temp = DoneToTotal_String.leftRef(DoneToTotal_String.indexOf(SLASH));
+                string_temp = ref_temp.toString();
+                progress_done = string_temp.toInt(&ok,10);
+                progress_done = progress_total - progress_done;
+                ui.OperationProgress -> setValue (progress_done);   //set the current progressbar value
+            }
+            if (outputString.contains("speedup is"))    //the process has finished, so if we're back fill it to 100%
+            {
+                ui.OperationProgress -> setRange(0,100);
+                ui.OperationProgress -> setValue (100);
+            }
+            if (outputString.contains("building file list"))
+            {
+                calculating = TRUE;
+                transferring = FALSE;
+                deleting = FALSE;
+            }
+            if (outputString.contains("files to consider"))
+            {
+                calculating = FALSE;
+                transferring = TRUE;
+                deleting = FALSE;
+            }
+            if (outputString.contains("deleting"))
+            {
+                calculating = FALSE;
+                transferring = FALSE;
+                deleting = TRUE;
+            }
+        }
+    }
+    if (pipeVssErrFile->open(QIODevice::ReadOnly | QIODevice::Text))
+    {
+            int i=size;
+        QTextStream stream(pipeVssErrFile);
+        stream.setCodec("UTF-8");
+        stream.seek(vssErrPos);
+        outputError="";
+        se=stream.readLine();
+        while(!se.isNull()&&i!=0){
+            outputError=outputError+se+"\n";
+            se=stream.readLine();
+            i--;
+        }
+
+        vssErrPos=stream.pos();
+        pipeVssErrFile->close();
+        if (outputError !="")
+        {
+            errorsFound++;
+            errorCount++;
+            ui.rsyncOutput->append(logFileUpdate("rsync-error", outputError, 0));
+        }
+    }
+    if (doVss == 2 && se.isNull() && s.isNull())
+    {
+        vssTimer->stop();
+        doVss = 0;
+        pipeVssFile->remove();
+        pipeVssErrFile->remove();
+        procFinished();
+
+    }
+}
+*/
 //updates Now Doing textBrowser ===============================================================================================================
 void luckyBackupWindow::setNowDoing()
 {
@@ -1058,8 +1362,13 @@ void luckyBackupWindow::setNowDoing()
     {
         NOWexecuting = FALSE;		//this is mainly used if the window close button (or alt+F4) is pressed
 
+        if (filesTransfered == 0)
+            bytesTransfered = 0;
+        
         nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
-                "</font></b><br>========================================="
+                "</font></b><br>" +
+                tr("Total files transfered") + " : <b>" + countStr.setNum(filesTransfered) + "</b> (" + convertBytes(QString::number(bytesTransfered),TRUE) +")<br>"
+                "========================================="
                 "<b><br><font color=blue>"+tr("All tasks completed")+" </font></b>";
         trayMessage =	tr("All tasks completed");
         if (DryRun)
@@ -1306,5 +1615,69 @@ void luckyBackupWindow::nextErrorJump()
     
     ui.rsyncOutput -> scrollToAnchor("error" + countStr.setNum(errorCount+1));
 }
+
+// convertBytes (QString,bool)
+// Converts a string of the form 67M to bytes and vice versa (eg 1024 -> 1KB)
+// if bool=FALSE then conversion string->bytes. If bool=TRUE then conversion bytes->string
+// =====================================================================================================
+QString luckyBackupWindow::convertBytes (QString byteLine,bool toWhat)
+{
+    QString returnThis = "";
+    bool ok;
+   
+    if (toWhat)           // convert bytes to string
+    {
+        QString multi = " bytes";
+        double bytesFLOAT = byteLine.toDouble(&ok);
+       
+        if (bytesFLOAT >=  1024)
+        {
+            bytesFLOAT = bytesFLOAT / 1024;
+            multi = "KB";
+        }
+        if (bytesFLOAT >= 1024)
+        {
+            bytesFLOAT = bytesFLOAT / 1024;
+            multi = "MB";
+        }
+        if (bytesFLOAT >= 1024)
+        {
+            bytesFLOAT = bytesFLOAT / 1024;
+            multi = "GB";
+        }
+        if (bytesFLOAT >= 1024)
+        {
+            bytesFLOAT = bytesFLOAT / 1024;
+            multi = "TB";
+        }
+        returnThis = (QString::number(bytesFLOAT));
+        if ( (returnThis.contains(".")) && ((returnThis.lastIndexOf(".") + 3) < returnThis.size()) )
+            returnThis.chop(returnThis.size() - returnThis.lastIndexOf(".") - 3);   // leave only 3 decimal points
+        returnThis = returnThis + multi;
+    }
+    else            // convert string to bytes
+    {
+        unsigned long int multiply = 1;
+        
+        if (byteLine.endsWith("K"))
+            multiply = 1024;
+        if (byteLine.endsWith("M"))
+            multiply = pow(1024,2);
+        if (byteLine.endsWith("G"))
+            multiply = pow(1024,3);
+        if (byteLine.endsWith("T"))
+            multiply = pow(1024,4);
+
+        if (    (byteLine.endsWith("K")) || (byteLine.endsWith("M")) ||
+                (byteLine.endsWith("G")) || (byteLine.endsWith("T")) )
+            byteLine.chop(1);
+        
+        unsigned long long int returnThisNo = byteLine.toDouble(&ok) * multiply;
+        returnThis = QString::number( returnThisNo);
+    }
+
+    return returnThis;
+
+}
 // end of executenow.cpp ---------------------------------------------------------------------------
 
