@@ -4,7 +4,7 @@ file containing all functions for luckybackupwindow
 ===============================================================================================================================
 ===============================================================================================================================
     This file is part of "luckyBackup" project
-    Copyright 2008-2012, Loukas Avgeriou
+    Copyright, Loukas Avgeriou
     luckyBackup is distributed under the terms of the GNU General Public License
     luckyBackup is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@ file containing all functions for luckybackupwindow
 project version	: Please see "main.cpp" for project version
 
 developer          : luckyb 
-last modified      : 01 Feb 2012
+last modified      : 11 Sep 2013
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -204,7 +204,7 @@ void luckyBackupWindow::retranslateUi()
     languageMenu	    -> setTitle(tr("&Language","This is a top menu item"));
     toolbarsMenu	    -> setTitle(tr("&Toolbars","This is a top menu item"));
     
-    if (notXnixRunning)
+    if (WINrunning)
     {
         actionSetWinPaths -> setText(tr("Set paths","This is a top menu action"));
         actionSetWinPaths -> setToolTip(tr("Set paths for rsync and ssh commands","This is a top menu action tooltip"));
@@ -310,7 +310,7 @@ void luckyBackupWindow::createActions()
     actionVisibleToolbarText -> setCheckable(TRUE);
     actionVisibleToolbarText -> setChecked(IsVisibleToolbarText);
     
-    if (notXnixRunning)
+    if (WINrunning)
     {
         actionSetWinPaths = new QAction("Set paths",this);
         connect( actionSetWinPaths, SIGNAL(triggered()), this, SLOT(setWinPaths()));      //menu action set paths
@@ -379,7 +379,7 @@ void luckyBackupWindow::createMenus()
     }
     
     // Win-OS2 paths sub-menu -------------------------------------------------------------------------------
-    if (notXnixRunning)
+    if (WINrunning)
         settingsMenu -> addAction(actionSetWinPaths);
 }
 // createToolbar =============================================================================================================================
@@ -678,6 +678,11 @@ int luckyBackupWindow::createCurrentProfile()
     if (!profile.exists())			//if the currentProfile does not exist, try to create it
     {
         TotalOperations = 0;	//Set the Operations list size to 0
+        
+        //Set email default options
+        emailNever = 1;
+        emailSubject = emailDefaultSubject;
+        emailBody = emailDefaultBody;
 
         if (currentProfile == defaultProfile)
             createData.append("<font color=blue><b>" + tr("creating default profile ...","Information window message") + "</font></b><br>");
@@ -780,11 +785,15 @@ bool luckyBackupWindow::saveSettings()
     out << "Visible_info_window="           << IsVisibleInfoWindow << "\n";         //output the visibility state of the info window
     out << "Quite_mode_output="             << showOnlyErrors << "\n";              //output the quite mode state of the commands output window
     
-    if (notXnixRunning)
+    if (WINrunning)
     {
         out << "\n[settings_non_*nix]\n";
         out << "win_rsync_path="            << rsyncCommandPath << "\n";            //output the rsync path for windows or OS2
         out << "win_ssh_path="              << sshCommandPath << "\n";              //output the ssh path for windows or OS2
+        out << "cygpath_path="              << cygpathCommand << "\n";
+        out << "dosdev_path="               << dosdevCommand << "\n";
+        out << "vshadowdir_path="           << vshadowDir << "\n";
+        out << "tempdir_path="              << tempDirPath << "\n";
     }
     
     out << "\n[Settings_file_end]" << "\n";	
@@ -858,6 +867,10 @@ bool luckyBackupWindow::loadSettings()
         
         if (SettingsLine.startsWith("win_rsync_path="))             rsyncCommandPath = SettingsLine.remove("win_rsync_path=");
         if (SettingsLine.startsWith("win_ssh_path="))               sshCommandPath = SettingsLine.remove("win_ssh_path=");
+        if (SettingsLine.startsWith("cygpath_path="))               cygpathCommand = SettingsLine.remove("cygpath_path=");
+        if (SettingsLine.startsWith("dosdev_path="))                dosdevCommand = SettingsLine.remove("dosdev_path=");
+        if (SettingsLine.startsWith("vshadowdir_path="))            vshadowDir = SettingsLine.remove("vshadowdir_path=");
+        if (SettingsLine.startsWith("tempdir_path=") && !isTempDirPath) tempDirPath = SettingsLine.remove("tempdir_path=");
     }
 
     settingsfile.close();
