@@ -4,7 +4,7 @@ Display a dialog. Adds a new or modifies an existing operation
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2012, Loukas Avgeriou
+     Copyright, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ Display a dialog. Adds a new or modifies an existing operation
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 17 Feb 2012
+ last modified      : 12 Jan 2014
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -53,9 +53,20 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
     uiM.label_executeAfterList -> setText ("<font color=red>" + comLabel + "</font>");
     
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    // Disable/hide stuff that is under testing/developement
-
-    uiM.toolBox_options         ->setItemEnabled (0,FALSE);    // different backend
+    // Various gui initialization
+    //uiM.toolBox_options         ->setItemEnabled (0,FALSE);    // different backend
+    
+    //Disable some stuff when windows is NOT running
+    if (!WINrunning)
+    {
+        uiM.checkBox_vss        -> setVisible(FALSE);
+        uiM.checkBox_restorent  -> setVisible(FALSE);
+        uiM.lineEdit_sshPasswordStr -> setVisible(FALSE);
+        uiM.lineEdit_sshOptions -> setVisible(FALSE);
+    }
+    else
+        uiM.checkBox_vss        -> setEnabled(FALSE);   // disable VSS until a better solution is found
+    
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     //connections ----------------------------------------------------------------------------------------------------
@@ -176,6 +187,19 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
     connect (uiM.toolButton_includeAddPattern, SIGNAL (clicked() ), signalMapper4 , SLOT (map()));
     connect(signalMapper4, SIGNAL(mapped( const int)), this, SLOT( getPattern( const int) )  );
     
+    // ssh password file default value
+    // I do not consider this a good idea, because the default option should be a blank field (no ssh key file)
+    // If the user clicks the browse button , he/she will be transfered to the ~/.ssh dir as default
+    /*
+    if ( (uiM.lineEdit_sshPassword -> text() == "" ) && (!WINrunning) )
+    {
+        if (!WINrunning)
+            uiM.lineEdit_sshPassword -> setText( myHome + SLASH +".ssh" + SLASH +"id_rsa");
+        else
+            uiM.lineEdit_sshPassword -> setText(luckyBackupDir+"id_rsa");
+    }
+    */
+    
     if (ArrayPosition < TotalOperations)    //if modify is pressed fill the fields first with existing operation data
         fillModifyWindow(Operation[ArrayPosition]);
     
@@ -259,8 +283,10 @@ void modifyDialog::browse(const int type)
                 uiM.lineEdit_rsyncPassword -> setText(modifyOS2Slashes(newLineEdit));
             break;
         //ssh password file browse button
-        case 5:    newLineEdit = QFileDialog::getOpenFileName (this, tr("Select ssh keyfile",
-            "file selection dialog title"), myHome + SLASH +".ssh");
+        case 5:    if (!WINrunning)
+                newLineEdit = QFileDialog::getOpenFileName (this, tr("Select ssh keyfile", "file selection dialog title"), myHome + SLASH +".ssh");
+            else
+                newLineEdit = QFileDialog::getOpenFileName (this, tr("Select ssh keyfile", "file selection dialog title"), luckyBackupDir);        
             if (newLineEdit != "")    //if something is selected indeed
                 uiM.lineEdit_sshPassword -> setText(modifyOS2Slashes(newLineEdit));
             break;
@@ -1175,12 +1201,14 @@ void modifyDialog::TaskTypeChanged(int type)
         uiM.label_snapshotsKeep -> setVisible(FALSE);
         uiM.spinBox_snapshotsKeep -> setVisible(FALSE);
         uiM.checkBox_backupContents -> setVisible(FALSE);
+        uiM.checkBox_deleteAfter -> setEnabled (FALSE);
     }
     else
     {
         uiM.label_snapshotsKeep -> setVisible(TRUE);
         uiM.spinBox_snapshotsKeep -> setVisible(TRUE);
         uiM.checkBox_backupContents -> setVisible(TRUE);
+        uiM.checkBox_deleteAfter -> setEnabled (TRUE);
     }
 }
 // Include tab stuff  changed=====================================================================================================
@@ -1308,7 +1336,9 @@ operation *modifyDialog::fillOperationArray()
     pTask -> SetRemoteSSH           ( uiM.checkBox_ssh -> isChecked() );
     pTask -> SetRemoteSSHPassword   ( uiM.lineEdit_sshPassword -> text() );
     pTask -> SetRemoteSSHPort       ( (uiM.lineEdit_sshPort -> text()).toInt() );
-
+    pTask -> SetRemoteSSHPasswordStr( uiM.lineEdit_sshPasswordStr -> text());
+    pTask -> SetRemoteSSHOptions    ( uiM.lineEdit_sshOptions -> text());
+    
     //set rsync options checkboxes -----------------------------------------------------------------------------------------------
     pTask -> SetOptionsUpdate       ( uiM.checkBox_update -> isChecked() );
     pTask -> SetOptionsOwnership    ( uiM.checkBox_ownership -> isChecked() );
@@ -1322,6 +1352,17 @@ operation *modifyDialog::fillOperationArray()
     pTask -> SetOptionsRecurse      ( uiM.checkBox_recurse -> isChecked() );
     pTask -> SetOptionsSuper        ( uiM.checkBox_super -> isChecked() );
     pTask -> SetOptionsNumericIDs   ( uiM.checkBox_numericIDs -> isChecked() );
+    // windows related rsync options
+    pTask -> SetOptionsRestorent    ( uiM.checkBox_restorent -> isChecked() );
+    pTask -> SetOptionsVss          ( uiM.checkBox_vss -> isChecked() );
+    pTask -> SetTempPath(tempDirPath);
+    pTask -> SetLuckyBackupDir      (luckyBackupDir);
+    pTask -> SetVshadowDir          (vshadowDir);
+    pTask -> SetDosdevCommand       (dosdevCommand);
+    pTask -> SetCygpathCommand      (cygpathCommand);
+    pTask -> SetRsyncCommand        (rsyncCommandPath);
+    pTask -> SetSshCommand          (sshCommandPath);
+    
     count = 0;    //read options list one by one
     while ( count < (uiM.listWidget_options -> count()) )
     {
@@ -1371,14 +1412,19 @@ void modifyDialog::fillModifyWindow(operation *pTask)
     {
         uiM.comboBox_Type -> setCurrentIndex(0);
         uiM.checkBox_backupContents -> setCheckState(Qt::Checked);
+        uiM.checkBox_deleteAfter -> setEnabled (TRUE);
     }
     if (pTask -> GetTypeDirName())
     {
         uiM.comboBox_Type -> setCurrentIndex(0);
         uiM.checkBox_backupContents -> setCheckState(Qt::Unchecked);
+        uiM.checkBox_deleteAfter -> setEnabled (TRUE);
     }
     if (pTask -> GetTypeSync())
+    {
         uiM.comboBox_Type -> setCurrentIndex(1);
+        uiM.checkBox_deleteAfter -> setEnabled (FALSE);
+    }
 
     uiM.lineEdit_source             -> setText    (pTask -> GetSource() );
     uiM.lineEdit_destination        -> setText    (pTask -> GetDestination() );
@@ -1422,6 +1468,8 @@ void modifyDialog::fillModifyWindow(operation *pTask)
     uiM.lineEdit_rsyncPassword      -> setText    (pTask -> GetRemotePassword() );
     uiM.checkBox_ssh                -> setChecked    (pTask -> GetRemoteSSH() );
     uiM.lineEdit_sshPassword        -> setText    (pTask -> GetRemoteSSHPassword() );
+    uiM.lineEdit_sshPasswordStr     -> setText    (pTask -> GetRemoteSSHPasswordStr() );
+    uiM.lineEdit_sshOptions         -> setText    (pTask -> GetRemoteSSHOptions() );
     if (pTask -> GetRemoteSSHPort() == 0)
         uiM.lineEdit_sshPort        -> setText    ("");
     else
@@ -1439,6 +1487,10 @@ void modifyDialog::fillModifyWindow(operation *pTask)
     uiM.checkBox_FATntfs            -> setChecked    (pTask -> GetOptionsFATntfs() );
     uiM.checkBox_super              -> setChecked    (pTask -> GetOptionsSuper() );
     uiM.checkBox_numericIDs         -> setChecked    (pTask -> GetOptionsNumericIDs() );
+    
+    uiM.checkBox_vss                -> setChecked    (pTask -> GetOptionsVss() );
+    uiM.checkBox_restorent          -> setChecked    (pTask -> GetOptionsRestorent() );
+    
     count=0;
     while ( count < (pTask -> GetOptionsListSize()) )
     {
@@ -1477,7 +1529,7 @@ void modifyDialog::fillModifyWindow(operation *pTask)
 // adds or removes a trailing "/" at the source & destination directory
 void modifyDialog::modifyTrailing()
 {   
-    // SLASH is "/" for *nix and "\\" for OS2
+    // SLASH is "/" for *nix and windows and "\\" for OS2
     
     QString sourceDir   = uiM.lineEdit_source -> text();
     QString destDir     = uiM.lineEdit_destination -> text();
@@ -1489,31 +1541,62 @@ void modifyDialog::modifyTrailing()
         if (destDir.endsWith(":"))      destDir.append(SLASH);
     }
 
-    if ((uiM.comboBox_Type -> currentIndex()==0) && (uiM.checkBox_backupContents -> isChecked()))           //Directory by contents
+    //Directory by contents - trailing slash at source & dest paths
+    if ((uiM.comboBox_Type -> currentIndex()==0) && (uiM.checkBox_backupContents -> isChecked()))
     {
-            if ( (!sourceDir.endsWith(SLASH)) && (sourceDir != ""))     sourceDir.append(SLASH);
-            if ( (!destDir.endsWith(SLASH)) && (destDir != ""))         destDir.append(SLASH);
+        if ( (!sourceDir.endsWith(XnixSLASH)) && (!sourceDir.endsWith(SLASH)) && (sourceDir != ""))
+        {
+            if (uiM.groupBox_remote -> isChecked() && uiM.radioButton_remoteSource -> isChecked())
+                sourceDir.append(XnixSLASH);
+            else
+                sourceDir.append(SLASH);
+        }
+        if ( (!destDir.endsWith(XnixSLASH)) &&(!destDir.endsWith(SLASH)) && (destDir != ""))
+        {
+            if (uiM.groupBox_remote -> isChecked() && uiM.radioButton_remoteDestination -> isChecked())
+                destDir.append(XnixSLASH);
+            else
+                destDir.append(SLASH);
+        }
     }
 
-    if ((uiM.comboBox_Type -> currentIndex()==0) && (!uiM.checkBox_backupContents -> isChecked()))        //Directory by name
+    //Directory by name - trailing slash only at  dest path not source
+    if ((uiM.comboBox_Type -> currentIndex()==0) && (!uiM.checkBox_backupContents -> isChecked()))
     {
-        if (notXnixRunning) //OS2 & win uses normal slashes "\" not unix ones "/"
+        if (notXnixRunning) //OS2 & win
         {
             if ( (sourceDir.endsWith(SLASH)) && (!sourceDir.endsWith(":"+SLASH)) )      sourceDir.chop(1);
-            if ( (!destDir.endsWith(SLASH)) && (destDir != "") )                        destDir.append(SLASH);
+            if ( (!destDir.endsWith(XnixSLASH)) && (!destDir.endsWith(SLASH)) && (destDir != "") )
+            {
+                if (uiM.groupBox_remote -> isChecked() && uiM.radioButton_remoteDestination -> isChecked())
+                    destDir.append(XnixSLASH);
+                else
+                    destDir.append(SLASH);
+            }
         }
-        else
+        else        //linux-unix
         {
             if ( (sourceDir.endsWith(SLASH)) && (sourceDir != SLASH) )            sourceDir.chop(1);
             if ( (!destDir.endsWith(SLASH)) && (destDir != "") )                  destDir.append(SLASH);
         }
     }
 
-    if (uiM.comboBox_Type -> currentIndex()==1)        //sync Directories
+    if (uiM.comboBox_Type -> currentIndex()==1)        //sync Directories - both paths have to have a trailing slash
     {
-       
-        if ( (!sourceDir.endsWith(SLASH)) && (sourceDir != ""))   sourceDir.append(SLASH);
-        if ( (!destDir.endsWith(SLASH)) && (destDir != ""))       destDir.append(SLASH);
+       if ((!sourceDir.endsWith(XnixSLASH)) && (!sourceDir.endsWith(SLASH)) && (sourceDir != ""))
+       {
+            if (uiM.groupBox_remote -> isChecked() && uiM.radioButton_remoteSource -> isChecked())
+                sourceDir.append(XnixSLASH);
+            else
+                sourceDir.append(SLASH);
+        }
+        if ( (!destDir.endsWith(XnixSLASH)) &&(!destDir.endsWith(SLASH)) && (destDir != ""))
+        {
+            if (uiM.groupBox_remote -> isChecked() && uiM.radioButton_remoteDestination -> isChecked())
+                destDir.append(XnixSLASH);
+            else
+                destDir.append(SLASH);
+        }
         
         uiM.checkBox_deleteAfter    -> setChecked    (FALSE);
         uiM.checkBox_update         -> setChecked    (TRUE);
@@ -1521,14 +1604,14 @@ void modifyDialog::modifyTrailing()
         uiM.checkBox_permissions    -> setChecked    (TRUE);
     }
     
-    if (WINrunning)     // some more adjustments for windows when the user wants to declare directly paths with "/" instead of "\" (normally for remote)
+    /*if (WINrunning)     // some more adjustments for windows when the user wants to declare directly paths with "/" instead of "\" (normally for remote)
     {      
         if (sourceDir.contains("/"))    sourceDir.replace(SLASH,"/");
         if (sourceDir.endsWith("//"))   sourceDir.chop(1);
         if (destDir.contains("/"))      destDir.replace(SLASH,"/");
         if (destDir.endsWith("//"))     destDir.chop(1);
-    }
-
+    }*/
+    
     uiM.lineEdit_source -> setText(sourceDir);
     uiM.lineEdit_destination -> setText(destDir);
 }
@@ -1537,7 +1620,7 @@ void modifyDialog::modifyTrailing()
 // function to change / to \ for OS2 (normaly when file dialog is used)
 QString modifyDialog::modifyOS2Slashes(QString pathToModify)
 {    
-    if (notXnixRunning)
+    if ( (notXnixRunning) && !pathToModify.startsWith("/") )
         pathToModify.replace("/",SLASH);
     
     return pathToModify;
