@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2012, Loukas Avgeriou
+     Copyright, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version    : Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 13 Feb 2012
+ last modified      : 11 Sep 2013
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -58,6 +58,8 @@ class operation
             itsOptionsFATntfs = FALSE;
             itsOptionsSuper = FALSE;
             itsOptionsNumericIDs = FALSE;
+            itsOptionsVss = FALSE;
+            itsOptionsRestorent = FALSE;
             itsIncludeFromFile = FALSE;
             itsExcludeFromFile = FALSE;
             itsExcludeGVFS = FALSE;
@@ -131,6 +133,8 @@ class operation
         QString GetRemoteUser () const          {return itsRemoteUser;}
         QString GetRemotePassword () const      {return itsRemotePassword;}
         QString GetRemoteSSHPassword () const   {return itsRemoteSSHPassword;}
+        QString GetRemoteSSHPasswordStr () const{return itsRemoteSSHPasswordStr;}
+        QString GetRemoteSSHOptions () const    {return itsRemoteSSHOptions;}
         int GetRemoteSSHPort () const           {return itsRemoteSSHPort;}
 
         bool GetOptionsUpdate () const          {return itsOptionsUpdate;}
@@ -145,6 +149,17 @@ class operation
         bool GetOptionsFATntfs() const          {return itsOptionsFATntfs;}
         bool GetOptionsSuper() const            {return itsOptionsSuper;}
         bool GetOptionsNumericIDs() const       {return itsOptionsNumericIDs;}
+        //windows related
+        bool GetOptionsVss () const             {return itsOptionsVss;}
+        bool GetOptionsRestorent () const       {return itsOptionsRestorent;}
+        QString GetTempPath () const            {return itsTempPath;}
+        QString GetLuckyBackupDir ( )           {return itsAppDir;}
+        QString GetVshadowDir () const          {return itsVshadowDir;}
+        QString GetRsyncCommand () const        {return itsRsyncCommand;}
+        QString GetDosdevCommand () const       {return itsDosdevCommand;}
+        QString GetCygpathCommand () const      {return itsCygpathCommand;}
+        QString GetSshCommand () const          {return itsSshCommand;}
+        // user options
         int GetOptionsListSize () const         {return itsOptionsList.size();}
         QString GetOptionsListItem (int itemPosition) const {return itsOptionsList.value(itemPosition);}
 
@@ -250,6 +265,8 @@ class operation
         void SetRemoteUser (QString RemoteUser)             { itsRemoteUser = RemoteUser;}
         void SetRemotePassword (QString RemotePassword)     { itsRemotePassword = RemotePassword;}
         void SetRemoteSSHPassword (QString RemoteSSHPassword) { itsRemoteSSHPassword = RemoteSSHPassword;}
+        void SetRemoteSSHPasswordStr (QString RemoteSSHPassword) { itsRemoteSSHPasswordStr = RemoteSSHPassword;}
+        void SetRemoteSSHOptions (QString RemoteSSHOptions) { itsRemoteSSHOptions = RemoteSSHOptions;}
         void SetRemoteSSHPort (int RemoteSSHPort)           { itsRemoteSSHPort = RemoteSSHPort;}
 
         // Command options - templates
@@ -265,6 +282,16 @@ class operation
         void SetOptionsFATntfs (bool OptionsFATntfs)        { itsOptionsFATntfs = OptionsFATntfs;}
         void SetOptionsSuper (bool OptionsSuper)            { itsOptionsSuper = OptionsSuper;}
         void SetOptionsNumericIDs (bool OptionsNumeriIDs)   { itsOptionsNumericIDs = OptionsNumeriIDs;}
+        // windows related options
+        void SetOptionsRestorent (bool Options)             { itsOptionsRestorent = Options;}
+        void SetOptionsVss (bool Options)                   { itsOptionsVss = Options;}
+        void SetTempPath (QString s)                        {itsTempPath = s;}
+        void SetLuckyBackupDir (QString s)                  { itsAppDir = s; }
+        void SetVshadowDir (QString s)                      {itsVshadowDir = s;}
+        void SetRsyncCommand (QString s)                    {itsRsyncCommand = s;}
+        void SetDosdevCommand (QString s)                   {itsDosdevCommand = s;}
+        void SetCygpathCommand (QString s)                  {itsCygpathCommand = s;}
+        void SetSshCommand (QString s)                      {itsSshCommand = s;}
         // Command options list - user defined
         void AddOptionsListItem (QString itemText)          { itsOptionsList.append(itemText);}
 
@@ -332,6 +359,8 @@ class operation
         QString itsRemoteUser;
         QString itsRemotePassword;
         QString itsRemoteSSHPassword;
+        QString itsRemoteSSHPasswordStr;
+        QString itsRemoteSSHOptions;
         int itsRemoteSSHPort;
 
         bool itsOptionsUpdate;
@@ -346,6 +375,17 @@ class operation
         bool itsOptionsFATntfs;
         bool itsOptionsSuper;
         bool itsOptionsNumericIDs;
+        //windows related variables
+        bool itsOptionsVss;
+        bool itsOptionsRestorent;
+        QString itsTempPath;
+        QString itsAppDir;
+        QString itsVshadowDir;
+        QString itsRsyncCommand;
+        QString itsDosdevCommand;
+        QString itsCygpathCommand;
+        QString itsSshCommand;
+        //user defined options list
         QStringList itsOptionsList;
 
         QStringList itsExecuteBeforeList;
